/*
 * Copyright 2009-2012 forwardfire.net All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 * 
 * * Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *   following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *   the following disclaimer in the documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package net.forwardfire.logstats.ejb.models;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;
import org.hibernate.annotations.ResultCheckStyle;
import org.hibernate.annotations.SQLInsert;

import net.forwardfire.vasc.annotations.VascDisplayName;
import net.forwardfire.vasc.annotations.VascFieldTemplate;

/**
 * LogStats
 *
 * @author Willem Cazander
 * @version 1.0 Jun 13, 2010
 */
@Entity
@Table(name = "log_stats")
@SequenceGenerator(name="LOG_STATS_ID_SEQ", sequenceName="log_stats_id_seq",allocationSize=1)
@Cache(usage=CacheConcurrencyStrategy.NONE)
@org.hibernate.annotations.Entity(selectBeforeUpdate=true,dynamicInsert=true,dynamicUpdate=true)
@SQLInsert(sql="SQL GENERATED BY dynamicInsert=true",check=ResultCheckStyle.NONE)
public class LogStats extends AbstractEntityBase {

	private static final long serialVersionUID = 10L;
	private Integer id = null;
	private Date    logDay = null;
	private Integer logHostId = null;
	private String  logHost = null;
	private Integer logSourceId = null;
	private String  logSource = null;
	private Integer logValueId = null;
	private String  logValue = null;
	private Integer timeTotal = null;
	private Integer timeMin = null;
	private Integer timeMax = null;
	private Integer timeAvg = null;
	private Integer valueCount = null;
	private String  valueText = null;
	private Date createdDate = null;
	private Date modifiedDate = null;
	
	/**
	 * @return the id
	 */
	@Id
	@GeneratedValue(strategy=GenerationType.SEQUENCE,generator="LOG_STATS_ID_SEQ")
	@Column(name="id",nullable=false)
	@VascFieldTemplate(templateClass=AbstractFieldTemplates.class)
	public Integer getId() {
		return id;
	}

	/**
	 * @param id the id to set
	 */
	public void setId(Integer id) {
		this.id = id;
	}

	/**
	 * @return the logDay
	 */
	@Column(name="log_day",nullable=false)
	@VascDisplayName
	public Date getLogDay() {
		return logDay;
	}

	/**
	 * @param logDay the logDay to set
	 */
	public void setLogDay(Date logDay) {
		this.logDay = logDay;
	}

	/**
	 * @return the logHostId
	 */
	@Column(name="log_host_id",nullable=true)
	public Integer getLogHostId() {
		return logHostId;
	}

	/**
	 * @param logHostId the logHostId to set
	 */
	public void setLogHostId(Integer logHostId) {
		this.logHostId = logHostId;
	}

	/**
	 * @return the logHost
	 */
	@Column(name="log_host",nullable=false)
	public String getLogHost() {
		return logHost;
	}

	/**
	 * @param logHost the logHost to set
	 */
	public void setLogHost(String logHost) {
		this.logHost = logHost;
	}

	/**
	 * @return the logSourceId
	 */
	@Column(name="log_source_id",nullable=true)
	public Integer getLogSourceId() {
		return logSourceId;
	}

	/**
	 * @param logSourceId the logSourceId to set
	 */
	public void setLogSourceId(Integer logSourceId) {
		this.logSourceId = logSourceId;
	}

	/**
	 * @return the logSource
	 */
	@Column(name="log_source",nullable=false)
	public String getLogSource() {
		return logSource;
	}

	/**
	 * @param logSource the logSource to set
	 */
	public void setLogSource(String logSource) {
		this.logSource = logSource;
	}

	/**
	 * @return the logValueId
	 */
	@Column(name="log_value_id",nullable=true)
	public Integer getLogValueId() {
		return logValueId;
	}

	/**
	 * @param logValueId the logValueId to set
	 */
	public void setLogValueId(Integer logValueId) {
		this.logValueId = logValueId;
	}

	/**
	 * @return the logValue
	 */
	@Column(name="log_value",nullable=false)
	public String getLogValue() {
		return logValue;
	}

	/**
	 * @param logValue the logValue to set
	 */
	public void setLogValue(String logValue) {
		this.logValue = logValue;
	}

	/**
	 * @return the timeTotal
	 */
	@Column(name="time_total",nullable=false)
	public Integer getTimeTotal() {
		return timeTotal;
	}

	/**
	 * @param timeTotal the timeTotal to set
	 */
	public void setTimeTotal(Integer timeTotal) {
		this.timeTotal = timeTotal;
	}

	/**
	 * @return the timeMin
	 */
	@Column(name="time_min",nullable=true)
	public Integer getTimeMin() {
		return timeMin;
	}

	/**
	 * @param timeMin the timeMin to set
	 */
	public void setTimeMin(Integer timeMin) {
		this.timeMin = timeMin;
	}

	/**
	 * @return the timeMax
	 */
	@Column(name="time_max",nullable=true)
	public Integer getTimeMax() {
		return timeMax;
	}

	/**
	 * @param timeMax the timeMax to set
	 */
	public void setTimeMax(Integer timeMax) {
		this.timeMax = timeMax;
	}

	/**
	 * @return the timeAvg
	 */
	@Column(name="time_avg",nullable=true)
	public Integer getTimeAvg() {
		return timeAvg;
	}

	/**
	 * @param timeAvg the timeAvg to set
	 */
	public void setTimeAvg(Integer timeAvg) {
		this.timeAvg = timeAvg;
	}

	/**
	 * @return the valueCount
	 */
	@Column(name="value_count",nullable=false)
	public Integer getValueCount() {
		return valueCount;
	}

	/**
	 * @param valueCount the valueCount to set
	 */
	public void setValueCount(Integer valueCount) {
		this.valueCount = valueCount;
	}

	/**
	 * @return the valueText
	 */
	@Column(name="value_text",nullable=false)
	public String getValueText() {
		return valueText;
	}

	/**
	 * @param valueText the valueText to set
	 */
	public void setValueText(String valueText) {
		this.valueText = valueText;
	}

	/**
	 * @return the createdDate
	 */
	@Column(name="created_date",nullable=false)
	@VascFieldTemplate(templateClass=AbstractFieldTemplates.class)
	public Date getCreatedDate() {
		return createdDate;
	}

	/**
	 * @param createdDate the createdDate to set
	 */
	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}

	/**
	 * @return the modifiedDate
	 */
	@Column(name="modified_date",nullable=false)
	@VascFieldTemplate(templateClass=AbstractFieldTemplates.class)
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * @param modifiedDate the modifiedDate to set
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}
}