/*
 * Copyright 2009-2012 forwardfire.net All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 * 
 * * Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *   following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *   the following disclaimer in the documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package net.forwardfire.logstats.ejb.models;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import net.forwardfire.vasc.annotations.VascField;
import net.forwardfire.vasc.annotations.VascFieldTemplate;
import net.forwardfire.vasc.annotations.VascModelReference;

/**
 * LogUserSetting
 *
 * @author Willem Cazander
 * @version 1.0 Jun 24, 2010
 */
@Entity
@Table(name = "log_user_setting")
@SequenceGenerator(name="LOG_USER_SETTING_ID_SEQ", sequenceName="log_user_setting_id_seq",allocationSize=1)
@Cache(usage=CacheConcurrencyStrategy.NONE)
public class LogUserSetting extends AbstractEntityBase {


	private static final long serialVersionUID = 10L;
	private Integer id = null;
	private LogUser logUser = null;
	private String name = null;
	private String value = null;
	private Date createdDate = null;
	private Date modifiedDate = null;
	
	/**
	 * @return the id
	 */
	@Id
	@GeneratedValue(strategy=GenerationType.SEQUENCE,generator="LOG_USER_SETTING_ID_SEQ")
	@Column(name="id",nullable=false)
	@VascFieldTemplate(templateClass=AbstractFieldTemplates.class)
	public Integer getId() {
		return id;
	}

	/**
	 * @param id the id to set
	 */
	public void setId(Integer id) {
		this.id = id;
	}

	/**
	 * @return the logUser
	 */
    @OneToOne(fetch=FetchType.LAZY)
    @JoinColumn(name="log_user_id",nullable=false)
    @VascField(list=false)
    @VascModelReference
	public LogUser getLogUser() {
		return logUser;
	}

	/**
	 * @param logUser the logUser to set
	 */
	public void setLogUser(LogUser logUser) {
		this.logUser = logUser;
	}

	/**
	 * @return the name
	 */
	@Column(name="name",nullable=false)
    @VascFieldTemplate(templateClass=AbstractFieldTemplates.class)
	public String getName() {
		return name;
	}

	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the value
	 */
	@Column(name="value",nullable=false)
	public String getValue() {
		return value;
	}

	/**
	 * @param value the value to set
	 */
	public void setValue(String value) {
		this.value = value;
	}

	/**
	 * @return the createdDate
	 */
	@Column(name="created_date",nullable=false)
	@VascFieldTemplate(templateClass=AbstractFieldTemplates.class)
	public Date getCreatedDate() {
		return createdDate;
	}

	/**
	 * @param createdDate the createdDate to set
	 */
	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}

	/**
	 * @return the modifiedDate
	 */
	@Column(name="modified_date",nullable=false)
	@VascFieldTemplate(templateClass=AbstractFieldTemplates.class)
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * @param modifiedDate the modifiedDate to set
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}
}