package net.forwardfire.logstats.ejb.models;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.ResourceBundle;

import net.forwardfire.logstats.ejb.models.LogData;
import net.forwardfire.logstats.ejb.models.LogHost;
import net.forwardfire.logstats.ejb.models.LogHostGroup;
import net.forwardfire.logstats.ejb.models.LogLevel;
import net.forwardfire.logstats.ejb.models.LogRightRole;
import net.forwardfire.logstats.ejb.models.LogSource;
import net.forwardfire.logstats.ejb.models.LogStats;
import net.forwardfire.logstats.ejb.models.LogUser;
import net.forwardfire.logstats.ejb.models.LogUserRightRole;
import net.forwardfire.logstats.ejb.models.LogUserSetting;
import net.forwardfire.logstats.ejb.models.LogValue;
import net.forwardfire.logstats.ejb.models.LogValueLine;
import net.forwardfire.logstats.ejb.models.LogValueType;
import net.forwardfire.vasc.annotations.VascBundleKeyGenerator;
import net.forwardfire.vasc.core.VascEntry;
import net.forwardfire.vasc.core.VascEntryField;
import net.forwardfire.vasc.core.actions.VascAction;

import junit.framework.TestCase;


public class I18nTests extends TestCase {

	public void testI18nKeys() throws Exception {
		VascBundleKeyGenerator gen = new VascBundleKeyGenerator();
		gen.setGenerateImage(false);
		gen.setGenerateHelpId(false);
		
		gen.addModelClass(LogData.class);
		gen.addModelClass(LogHost.class);
		gen.addModelClass(LogHostGroup.class);
		gen.addModelClass(LogLevel.class);
		gen.addModelClass(LogRightRole.class);
		gen.addModelClass(LogSource.class);
		gen.addModelClass(LogStats.class);
		gen.addModelClass(LogUser.class);
		gen.addModelClass(LogUserRightRole.class);
		gen.addModelClass(LogUserSetting.class);
		gen.addModelClass(LogValue.class);
		gen.addModelClass(LogValueLine.class);
		gen.addModelClass(LogValueType.class);

		// print stuff
		StringBuffer buf = new StringBuffer(2000);
		
		int totalModels = gen.getModelClasses().size();
		buf.append("\n===Model classes: "+totalModels);

		//buf.append("\n======== START ALL =========\n");
		//gen.generateKeys(buf);
		//buf.append("\n======== END ALL =========\n");
		
		buf.append("\n======== START MISSING =========\n");
		gen.generateMissingKeys(buf, ResourceBundle.getBundle("net/forwardfire/logstats/resources/i18n/LogstatsBundleEJB"));
		buf.append("\n======== END MISSING =========\n");
		
		buf.append("\n======== START REMOVE =========\n");
		gen.generateRemoveKeys(buf, ResourceBundle.getBundle("net/forwardfire/logstats/resources/i18n/LogstatsBundleEJB"),"vasc(.*)|validator(.*)|generic(.*)");
		buf.append("\n======== END REMOVE =========\n");
		
		buf.append("\n======== START DUPS =========\n");
		for (String dup:gen.getDubIdNameKeys()) {
			buf.append(dup);
			buf.append('\n');
		}
		buf.append("\n======== END DUPS =========\n");
		
		System.out.println(buf);

	}
	
	
	
	private Map<String,String> keys = new HashMap<String,String>(300);
	
	public void testVascI18nKeys() throws Exception {

		// load sql
		//XtesManager xtes = new XtesManager();
		//xtes.loadAll();
		
		// load vasc xml
		/*
		VascManager vasc = new VascManager();
		vasc.xtesManager = xtes;
		VascController controller = vasc.getVascController();

		StringBuffer buf = new StringBuffer(2000);
		
		if (keys.isEmpty()==false) {
			keys.clear();
		}
		
		
		for (String id:controller.getVascEntryController().getVascEntryIds()) {
			VascEntry entry = controller.getVascEntryController().getVascEntryById(id);			
			generateKeys(entry);
		}
		
		//buf.append("\n======== START ALL =========\n");
		//printKeys(buf);
		//buf.append("\n======== END ALL =========\n");
		
		buf.append("\n======== START MISSING =========\n");
		generateMissingKeys(buf, ResourceBundle.getBundle("net/forwardfire/logstats/resources/i18n/LogstatsBundleEJB"));
		buf.append("\n======== END MISSING =========\n");
		
		buf.append("\n======== START REMOVE =========\n");
		generateRemoveKeys(buf, ResourceBundle.getBundle("net/forwardfire/logstats/resources/i18n/LogstatsBundleEJB"),"vasc.validator(.*)|validator(.*)|generic(.*)");
		buf.append("\n======== END REMOVE =========\n");
		
		// So stats
		buf.append("Total entries: "+controller.getVascEntryController().getVascEntryIds().size()+"\n");
		int lists = 0;
		int edits = 0;
		int links = 0;
		int fields = 0;
		int rowActions = 0;
		for (String id:controller.getVascEntryController().getVascEntryIds()) {
			VascEntry entry = controller.getVascEntryController().getVascEntryById(id);			
			if (entry.isVascAdminList()) {
				lists++;
			}
			if (entry.isVascAdminEdit()) {
				edits++;
			}
			links+=entry.getVascLinkEntries().size();
			fields+=entry.getVascEntryFields().size();
			rowActions+=entry.getRowActions().size();
		}
		buf.append("Total lists: "+lists+"\n");
		buf.append("Total edits: "+edits+"\n");
		buf.append("Total links: "+links+"\n");
		buf.append("Total fields: "+fields+"\n");
		buf.append("Total rowActions: "+rowActions+"\n");
			
		System.out.println(buf);
		*/
	}
	
	public void generateKeys(VascEntry entry) {
		appendKey(entry.getName(),entry.getId());
		appendKey(entry.getListDescription(),"View "+entry.getId());
		appendKey(entry.getEditDescription(),"Edit "+entry.getId());
		appendKey(entry.getDeleteDescription(),"Delete "+entry.getId());
		
		for (VascAction action:entry.getGlobalActions()) {
			appendKey(action.getName(),action.getId());
			appendKey(action.getDescription(),action.getId());			
		}
		for (VascAction action:entry.getRowActions()) {
			appendKey(action.getName(),action.getId());
			appendKey(action.getDescription(),action.getId());			
		}
		for (VascAction action:entry.getColumnActions()) {
			appendKey(action.getName(),action.getId());
			appendKey(action.getDescription(),action.getId());			
		}
		for (VascEntryField option:entry.getListOptions()) {     	
			appendKey(option.getName(),option.getId());
		}
	}
	
	public void printKeys(StringBuffer buffer) {		
		List<String> keys2 = new ArrayList<String>(keys.keySet());
		Collections.sort(keys2);
		for (String key:keys2) {
			String value = keys.get(key);
			buffer.append(key);
			buffer.append(" = ");
			buffer.append(value);
			buffer.append('\n');
		}
	}
	
	public void generateMissingKeys(StringBuffer buffer,ResourceBundle bundle) {
		List<String> keys2 = new ArrayList<String>(keys.keySet());
		keys2.removeAll(bundle.keySet());
		Collections.sort(keys2);
		for (String key:keys2) {
			String value = keys.get(key);
			buffer.append(key);
			buffer.append(" = ");
			buffer.append(value);
			buffer.append('\n');
		}
	}
	
	public void generateRemoveKeys(StringBuffer buffer,ResourceBundle bundle,String excludeRegex) {
		List<String> keys2 = new ArrayList<String>(bundle.keySet());
		keys2.removeAll(keys.keySet());
		Collections.sort(keys2);
		for (String key:keys2) {
			// exlude code and user keys
			if (excludeRegex!=null && key.matches(excludeRegex)) {
				continue;
			}
			buffer.append(key);
			buffer.append('\n');
		}
	}
	
	
    private void appendKey(String key,String value) {
    	if (key==null) {
    		return; // hackje untill we have x4o templating
    	}
    	if (keys.containsKey(key)) {
    		return;
    	}
    	keys.put(key, value);
    }
}
