/*
 * Copyright 2009-2012 forwardfire.net All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 * 
 * * Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *   following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *   the following disclaimer in the documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package net.forwardfire.logstats.web.filters;

import java.io.IOException;
import java.util.logging.Logger;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.forwardfire.logstats.web.beans.UserController;



/**
 * Filter in and out logs of users.
 *
 * @author Willem Cazander
 * @version 1.0 Nov 12, 2009
 */
public class UserFilter implements Filter {

	private static final long serialVersionUID = 10l;
	private Logger logger = null; 

	/**
	 * @see javax.servlet.Filter#destroy()
	 */
	public void destroy() {
		logger = null;
	}

	/**
	 * @see javax.servlet.Filter#init(javax.servlet.FilterConfig)
	 */
	public void init(FilterConfig config) throws ServletException {
		logger = Logger.getLogger(UserFilter.class.getName());
	}
	
	/**
	 * @see javax.servlet.Filter#doFilter(javax.servlet.ServletRequest, javax.servlet.ServletResponse, javax.servlet.FilterChain)
	 */
	public void doFilter(ServletRequest servletRequest,ServletResponse servletResponse,FilterChain chain) throws IOException, ServletException {
	
		HttpServletRequest  request  = (HttpServletRequest)servletRequest;
		HttpServletResponse response = (HttpServletResponse)servletResponse;
		
		// Let all anymous user to next filter
		if (request.getUserPrincipal()==null) {
			chain.doFilter(request, response);
			return;
		}
		
		UserController userController = (UserController)request.getSession().getAttribute("userController");
		if (userController==null) {
			logger.info("Can't create userController for first request auth: "+request.getUserPrincipal());
			chain.doFilter(request, response);
			return;			
		}
		if (userController.isUserLoggedin()==false) {
			userController.loginFilter();
			
			// size session time to 20min
			request.getSession().setMaxInactiveInterval(20*60*1000);
		}
		
		// Check for logout
		String path = request.getRequestURI();
		if (path.endsWith("login/logout.jsf")) {
			userController.logoutFilter();
			request.getSession().invalidate();
		}
		
		// do rest of chain.
		chain.doFilter(request, response);
	}

}